<h1 align="center" >Socratic</h1>

<p align="center">
  <a href="https://pypi.python.org/pypi/socratic"><img src="https://badge.fury.io/py/socratic.svg"></a>
  <a href="https://travis-ci.org/gruns/socratic"><img src="https://img.shields.io/travis/dvvolynkin/socratic.svg"></a>
  <a href="http://unlicense.org/"><img src="https://img.shields.io/pypi/l/socratic.svg"></a>
  <a href="https://pypi.python.org/pypi/socratic"><img src="https://img.shields.io/pypi/pyversions/socratic.svg"></a>
</p>


### Socratic - very simple question-answer dialogue system based on python generators.


With socratic dialogue-system you can have no state machine and design dialogue only with functions

Socratic [permissively licensed](LICENSE.txt), and supports Python >= 3.7.


### Installation

```bash
$ pip install socratic
``` 
